@@ -1,5 +1,5 @@
 /**
- * Isotope v1.5.04
+ * Isotope v1.5.05
  * An exquisite jQuery plugin for magical layouts
  * http://isotope.metafizzy.co
  *
@@ -732,7 +732,7 @@
       
       var instance = this;
       this.addItems( $content, function( $newAtoms ) {
-        var $newFilteredAtoms = instance._filter( $newAtoms, true );
+        var $newFilteredAtoms = instance._filter( $newAtoms );
         instance._addHideAppended( $newFilteredAtoms );
         instance._sort();
         instance.reLayout();
@@ -782,13 +782,25 @@
     },
     
     // removes elements from Isotope widget
-    remove : function( $content ) {
+    remove: function( $content ) {
+      // remove elements from Isotope instance in callback
+      var instance = this;
+      var removeContent = function() {
+        instance.$allAtoms = instance.$allAtoms.not( $content );
+        $content.remove();
+      };
 
-      this.$allAtoms = this.$allAtoms.not( $content );
-      this.$filteredAtoms = this.$filteredAtoms.not( $content );
+      if ( $content.filter( ':not(.' + this.options.hiddenClass + ')' ).length ) {
+        // if any non-hidden content needs to be removed
+        this.styleQueue.push({ $el: $content, style: this.options.hiddenStyle });
+        this.$filteredAtoms = this.$filteredAtoms.not( $content );
+        this._sort();
+        this.reLayout( removeContent );
+      } else {
+        // remove it now
+        removeContent();
+      }
 
-      $content.remove();
-      
     },
     
     shuffle : function( callback ) {
